@@ -88,18 +88,14 @@ AudioOutput::Start ()
 void
 AudioOutput::Stop ()
 {
-	Thread::Stop ();
+	Thread::Kill ();
 	Thread::Join ();
 	out.close ();
 }
 
-extern void sched_realtime ();
-
 void 
 AudioOutput::ThreadAction	()
 {
-	sched_realtime ();
-	
 	int bufsize = config->buffer_size;
 	while (!ShouldStop ())
 	{
