@@ -9,12 +9,10 @@ class SoftLimiter
 {
 public:
 	void	SetSampleRate	(int rate);
-	void	isStereo(){ch=2;};
 	void	Process	(float *l, float *r, unsigned, int stride=1);
   private:
     float *buffer;
 	double xpeak, attack, release, thresh;
-	int ch;
 };
 
 #endif
