@@ -418,7 +418,7 @@ GUI::init()
 	Preset *preset = &(preset_controller->getCurrentPreset());
 	
 	
-	for (int i=0; i<kControls_End; i++) {
+	for (int i=0; i<kAmsynthParameterCount; i++) {
 		Parameter &param = preset->getParameter(i);
 		m_adjustments[i] = (GtkAdjustment *) gtk_adjustment_new (
 			param.getValue(),
@@ -735,7 +735,7 @@ GUI::UpdateParameter(Param paramID, float paramValue)
 void
 GUI::UpdateParameterOnMainThread(Param paramID, float)	// called whenever a parameter value has changed
 {
-	if (0 <= paramID && paramID < kControls_End)
+	if (0 <= paramID && paramID < kAmsynthParameterCount)
 	{
 		const Parameter &param = preset_controller->getCurrentPreset().getParameter(paramID);
 	
@@ -926,27 +926,13 @@ GUI::tuning_reset	( )
 	}
 }
 
-static gchar *which(gchar *command)
-{
-	gint exit_status = -1;
-	gchar *standard_output = NULL;
-	gchar *argv[] = { (gchar *)"/usr/bin/which", (gchar *)command };
-	g_spawn_sync(NULL, argv, NULL, G_SPAWN_STDERR_TO_DEV_NULL, NULL, NULL, &standard_output, NULL, &exit_status, NULL);
-	if (exit_status != 0)
-	{
-		g_free(standard_output);
-		return NULL;
-	}
-	return standard_output;
-}
-
 // returns 0 if executable was found
 int
 GUI::command_exists	(const char *command)
 {
-	gchar *path = which((gchar *)command);
-	if (path) g_free(path);
-	return path == NULL ? 1 : 0;
+	std::string cmdline = "which " + std::string(command);
+	int result = system(cmdline.c_str());
+	return result;
 }
 
 void
