@@ -37,7 +37,7 @@ public:
 		PARAM_POWER		// controlValue = offset + value ^ base
 	};
 
-					Parameter		(const string name = "unused", Param id = kControls_End, 
+					Parameter		(const string name = "unused", Param id = kAmsynthParameterCount, 
 									 float value = 0.0, float min = 0.0, float max = 1.0, float inc = 0.0,
 									 ControlType = PARAM_DIRECT, float base = 1.0, float offset = 0.0,
 									 const string label = "");
@@ -90,12 +90,17 @@ public:
 	// The label assocaited with this Parameter. (e.g. "seconds")
 	const string	getLabel		() const { return _label; }
 	
+	const std::vector<std::string> & parameterValueStrings() const { return _parameterValueStrings; }
+	
+	void setParameterValueStrings(const char **names, size_t count);
+	
 private:
 	Param							mParamId;
 	string							_name, _label;
 	int								_controlMode;
 	float							_value, _min, _max, _step, _controlValue, _base, _offset;
 	vector<UpdateListener*>			_updateListeners;
+	std::vector<std::string>		_parameterValueStrings;
 };
 
 #endif
