@@ -5,6 +5,8 @@
 #ifndef _PRESET_H
 #define _PRESET_H
 
+#ifdef __cplusplus
+
 #include <string>
 #include <vector>
 #include "Parameter.h"
@@ -45,3 +47,16 @@ private:
 };
 
 #endif
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+void get_parameter_properties(int parameter_index, double *minimum, double *maximum, double *default_value, double *step_size);
+
+#ifdef __cplusplus
+}
+#endif
+
+#endif
+
