@@ -49,6 +49,15 @@ PresetController::selectPreset		(const string name)
 	return -1;
 }
 
+bool
+PresetController::containsPresetWithName(const string name)
+{
+	for (int i=0; i<kNumPresets; i++) 
+		if (getPreset(i).getName() == name) 
+			return true;
+	return false;
+}
+
 Preset&
 PresetController::getPreset			(const string name)
 {
@@ -74,59 +83,19 @@ int
 PresetController::exportPreset		(const string filename)
 {
 	ofstream file( filename.c_str(), ios::out );
-	file << "amSynth1.0preset" << endl;
-	
-	file << "<preset> " << "<name> " << currentPreset.getName() << endl;
-	for (unsigned n = 0; n < currentPreset.ParameterCount(); n++)
-	{
-		file << "<parameter> " << currentPreset.getParameter(n).getName() 
-		<< " " << currentPreset.getParameter(n).getValue() << endl;
-	}
+	file << currentPreset.toString();
 	file.close();
-	
 	return 0;
 }
 
 int
 PresetController::importPreset		(const string filename)
 {	
-	ifstream file( filename.c_str(), ios::in );
-	char buffer[100];
-  
-	if (file.bad())	return -1;
-  
-	file >> buffer;
-  
-	if (string(buffer) != "amSynth1.0preset") return -1;
-  
-	file >> buffer;
-	if (string(buffer) == "<preset>") {
-		file >> buffer;
-		
-		//get the preset's name
-		file >> buffer;
-		string presetName = "Imported: ";
-		presetName += string(buffer);
-		file >> buffer;
-		while (string(buffer) != "<parameter>") {
-			presetName += " ";
-			presetName += string(buffer);
-			file >> buffer;
-		}
-		currentPreset.setName(presetName); 
-		//get the parameters
-		while (string(buffer) == "<parameter>") {
-			string name;
-			file >> buffer;
-			name = string(buffer);
-			file >> buffer;
-			if(name!="unused")
-				currentPreset.getParameter(name).setValue( atof(buffer) );
-			file >> buffer;
-		}
-		currentPreset.setName(presetName);
-		notify ();
-	} else file.close();
+	ifstream ifs( filename.c_str(), ios::in );
+	std::string str( (std::istreambuf_iterator<char>(ifs)), std::istreambuf_iterator<char>() );
+	if (!currentPreset.fromString( str )) return -1;
+	currentPreset.setName("Imported: " + currentPreset.getName());
+	notify ();
 	return 1;
 }
 
@@ -172,7 +141,7 @@ PresetController::loadPresets		(const char *filename)
 	cout << "<PresetController::loadPresets()>" << endl;
 #endif
 	ifstream file( filename, ios::in );
-	char buffer[100];
+	string buffer;
   
 	if (file.bad()) {
 #ifdef _DEBUG
@@ -183,7 +152,7 @@ PresetController::loadPresets		(const char *filename)
   
 	file >> buffer;
   
-	if (string(buffer) != "amSynth") {
+	if (buffer != "amSynth") {
 #ifdef _DEBUG
 		cout <<
 		"<PresetController::loadPresets()> not an amSynth file, bailing out"
@@ -195,17 +164,17 @@ PresetController::loadPresets		(const char *filename)
 	int preset = -1;
 	file >> buffer;
 	while (file.good()) {
-		if (string(buffer) == "<preset>") {
+		if (buffer == "<preset>") {
 			preset++;
 			file >> buffer;
 			
 			//get the preset's name
 			file >> buffer;
-			string presetName = string(buffer);
+			string presetName(buffer);
 			file >> buffer;
-			while (string(buffer) != "<parameter>") {
+			while (buffer != "<parameter>") {
 				presetName += " ";
-				presetName += string(buffer);
+				presetName += buffer;
 				file >> buffer;
 			}
 #ifdef _DEBUG
@@ -214,10 +183,10 @@ PresetController::loadPresets		(const char *filename)
 #endif
 			presets[preset].setName(presetName);
 			//get the parameters
-			while (string(buffer) == "<parameter>") {
+			while (buffer == "<parameter>") {
 				string name;
 				file >> buffer;
-				name = string(buffer);
+				name = buffer;
 				file >> buffer;
 #ifdef _DEBUG
 				cout << "<PresetController::loadPresets()>: Parameter:- name="
@@ -227,12 +196,7 @@ PresetController::loadPresets		(const char *filename)
 				Parameter &param = presets[preset].getParameter(name);
 				if (param.getName() == name) // make sure parameter name is supported
 				{
-					float fval = 0.0f;
-					// atof() and friends are affected by currently configured locale,
-					// which can change the decimal point character.
-					std::istringstream istr(buffer);
-					istr.imbue(std::locale("C")); // be absolutely sure of the locale
-					istr >> fval;
+					float fval = Parameter::valueFromString(buffer);
 					param.setValue(fval);
 					if (param.getValue() != fval)
 					{
