@@ -9,6 +9,7 @@
 
 #include "UpdateListener.h"
 #include "MidiController.h"
+#include "TuningMap.h"
 
 class VoiceBoard;
 class SoftLimiter;
@@ -33,11 +34,16 @@ public:
 	virtual void HandleMidiSustainPedal(uchar value);
 
 	void	SetMaxVoices	(int voices) { mMaxVoices = voices; }
+	int		GetMaxVoices	() { return mMaxVoices; }
 	int		GetActiveVoices	() { return mActiveVoices; }
 
 	// processing with stride (interleaved) is not functional yet!!!
 	void	Process			(float *l, float *r, unsigned nframes, int stride=1);
 
+	int	loadScale		(const string & sclFileName);
+	int	loadKeyMap		(const string & kbmFileName);
+	void	defaultTuning		();
+
 private:
 	void	purgeVoices		();
 
@@ -46,13 +52,20 @@ private:
 
 	char	keyPressed[128], sustain;
 	bool	active[128];
+	bool	mute[128];
 	std::vector<VoiceBoard*>	_voices;
 	
 	SoftLimiter	*limiter;
 	revmodel	*reverb;
 	Distortion	*distortion;
+	
+	float	*mBuffer;
 
 	float	mMasterVol;
+	float	mPitchBendRangeSemitones;
+
+	TuningMap	tuningMap;
+	void		updateTuning	();
 };
 
 #endif
