@@ -5,8 +5,11 @@
 #include <cmath>
 #include <cstdlib>		// required for rand()
 #include <iostream>
+#include <limits.h>
 #include "Oscillator.h"
 
+#define ALIAS_REDUCTION
+
 // fmod is sloooooooooooow.
 inline float ffmodf (float x, float y) {
 	while (x > y) x -= y;
@@ -19,7 +22,6 @@ Oscillator::Oscillator()
 ,	waveform (Waveform_Sine)
 ,	rate (44100)
 ,	random_count (0)
-,	period (0)
 ,	reset_offset (4096)
 ,	reset_period (4096)
 ,	sync (NULL)
@@ -90,6 +92,13 @@ Oscillator::sqr(float foo)
 void 
 Oscillator::doSquare(float *buffer, int nFrames)
 {
+	// pulsewidth 0 =  50% duty cycle
+	// pulsewidth 1 = 100% duty cycle (i.e. pure DC)
+	// therefore clamp maximum value to make sure some sound is produced!
+	const float kMaxPulseWidth = 0.9f;
+	if (mPulseWidth > kMaxPulseWidth)
+		mPulseWidth = kMaxPulseWidth;
+
     for (int i = 0; i < nFrames; i++) {
 		buffer[i] = sqr(rads += (twopi_rate * freq));
 		//-- sync to other oscillator --
@@ -123,6 +132,16 @@ Oscillator::saw(float foo)
 void 
 Oscillator::doSaw(float *buffer, int nFrames)
 {
+#ifdef ALIAS_REDUCTION
+	// Clamp the maximum slope to reduce amount of aliasing in high octaves.
+	// This is not proper anti-aliasing ;-)
+	const float requestedPW = mPulseWidth;
+	const float kAliasReductionAmount = 2.0f;
+	const float f = requestedPW - (kAliasReductionAmount * freq / (float)rate);
+	if (mPulseWidth > f)
+		mPulseWidth = f;
+#endif
+
     for (int i = 0; i < nFrames; i++) {
 		buffer[i] = saw(rads += (twopi_rate * freq));
 		//-- sync to other oscillator --
@@ -135,6 +154,21 @@ Oscillator::doSaw(float *buffer, int nFrames)
 				sync_offset = i;		// remember the offset
 	}
     rads = ffmodf((float)rads, (float)TWO_PI);
+
+#ifdef ALIAS_REDUCTION
+	mPulseWidth = requestedPW;
+#endif
+}
+
+static const float kTwoOverUlongMax = 2.0f / (float)ULONG_MAX;
+
+static inline float randf()
+{
+	// Calculate pseudo-random 32 bit number based on linear congruential method.
+	// http://www.musicdsp.org/showone.php?id=59
+	static unsigned long random = 22222;
+	random = (random * 196314165) + 907633515;
+	return (float)random * kTwoOverUlongMax - 1.0f;
 }
 
 void 
@@ -144,7 +178,7 @@ Oscillator::doRandom(float *buffer, int nFrames)
     for (int i = 0; i < nFrames; i++) {
 	if (random_count > period) {
 	    random_count = 0;
-		random = ((float)::rand() / (RAND_MAX / 2.0f)) - 1.0f;
+		random = randf();
 	}
 	random_count++;
 	buffer[i] = random;
@@ -155,5 +189,5 @@ void
 Oscillator::doNoise(float *buffer, int nFrames)
 {
     for (int i = 0; i < nFrames; i++)
-		buffer[i] = ((float)::rand() / (RAND_MAX / 2.0f)) - 1.0f;
+		buffer[i] = randf();
 }
