@@ -47,7 +47,7 @@ class VoiceBoard
 public:
 	VoiceBoard(const VoiceBoardProcessMemory * mem);
 
-	int	getState		();
+	bool	isSilent		();
 	void	triggerOn		();
 	void	triggerOff		();
 	void	setVelocity		(float velocity);
@@ -93,6 +93,7 @@ private:
 	ADSR 			filter_env;
 	
 	// amp section
+	IIRFilterFirstOrder _vcaFilter;
 	float			mAmpModAmount;
 	ADSR 			amp_env;
 };
