@@ -7,7 +7,7 @@
 
 #include "AudioDriver.h"
 
-#ifdef with_alsa
+#ifdef WITH_ALSA
 #define ALSA_PCM_OLD_HW_PARAMS_API
 #define ALSA_PCM_OLD_SW_PARAMS_API
 #include <alsa/asoundlib.h>
@@ -36,7 +36,7 @@ private:
 	int		_format;
 	unsigned char	*audiobuf;
 	Config		*config;
-#ifdef with_alsa
+#ifdef WITH_ALSA
 	snd_pcm_t		*playback_handle;
 	snd_pcm_hw_params_t	*hw_params;
 	snd_pcm_sw_params_t	*sw_params;
