@@ -2,6 +2,7 @@
  * (c) 2001-2005 Nick Dowell
  */
 
+#include "main.h"
 #include "GUI/gui_main.h"
 #include "MidiController.h"
 #include "VoiceAllocationUnit.h"
@@ -9,6 +10,7 @@
 #include "JackOutput.h"
 #include "Config.h"
 #include "../config.h"
+#include "lash.h"
 
 #if __APPLE__
 #include "drivers/CoreAudio.h"
@@ -27,6 +29,8 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
+#include "Effects/denormals.h"
+
 using namespace std;
 
 #ifdef _DEBUG
@@ -35,6 +39,10 @@ using namespace std;
 #define DEBUGMSG( ... )
 #endif
 
+#ifndef DEFAULT_PREFIX
+#define DEFAULT_PREFIX "/usr/local"
+#endif
+
 
 string help_text =
 "usage: amSynth [options]\n\
@@ -56,7 +64,6 @@ options:\n\
 
 Config config;
 
-
 #ifdef ENABLE_REALTIME
 void sched_realtime()
 {
@@ -115,9 +122,8 @@ void install_default_files_if_reqd()
 		printf ("Will fallback to hardcoded default path.\n"); 
 	}
 	
-	#define DEFAULT_PREFIX "/usr/local"
 	char * homedir = getenv ("HOME");
-	char * data_dir = br_find_data_dir (DEFAULT_PREFIX"/share");
+	char * data_dir = br_find_data_dir (DEFAULT_PREFIX "/share");
 	char * amsynth_data_dir = br_strcat (data_dir, "/amSynth");
 	char * factory_controllers = br_strcat (amsynth_data_dir, "/Controllersrc");
 	char * factory_config = br_strcat (amsynth_data_dir, "/rc");
@@ -155,11 +161,33 @@ void install_default_files_if_reqd()
 
 void ptest ();
 
+static MidiController *midi_controller = NULL;
+static PresetController *presetController = NULL;
+
 GenericOutput * open_audio()
 {	
 #if	__APPLE__
 
-	return CreateCoreAudioOutput();
+	if (config.audio_driver == "jack" ||
+		config.audio_driver == "JACK" ){
+		JackOutput *jack = new JackOutput();
+		if (jack->init(config) != 0) {
+			delete jack;
+			return NULL;
+		}
+		if (config.current_midi_driver == "JACK" ||
+			config.current_midi_driver == "jack" ){
+			jack->setMidiHandler(midi_controller);
+			printf("Using JACK MIDI\n");
+		}
+		return jack;
+	}
+
+	if (config.audio_driver == "coreaudio" ||
+		config.audio_driver == "auto")
+		return CreateCoreAudioOutput();
+
+	return NULL;
 	
 #else
 
@@ -168,7 +196,14 @@ GenericOutput * open_audio()
 	{
 		JackOutput *jack = new JackOutput();
 		if (jack->init(config) == 0)
+		{
+			if (config.current_midi_driver == "JACK" ||
+				config.current_midi_driver == "jack" )
+			{
+				jack->setMidiHandler(midi_controller);
+			}
 			return jack;
+		}
 		else
 		{
 			std::string jack_error = jack->get_error_msg();
@@ -194,11 +229,15 @@ void fatal_error(const std::string & msg)
 	exit(1);
 }
 
+unsigned amsynth_timer_callback();
+
 int main( int argc, char *argv[] )
 {
 #ifdef ENABLE_REALTIME
 	sched_realtime();
 #endif
+	
+	disable_denormals();
 
 	// need to drop our suid-root permissions :-
 	// GTK will not work SUID for security reasons..
@@ -217,10 +256,13 @@ int main( int argc, char *argv[] )
 		"This is free software, and you are welcome to redistribute it\n"
 		"under certain conditions; see the file COPYING for details\n";
 
-	// bool jack = false;
-	
+	int initial_preset_no = 0;
+
+	// needs to be called before our own command line parsing code
+	amsynth_lash_process_args(&argc, &argv);
+
 	int opt;
-	while( (opt=getopt(argc, argv, "vhstdzm:c:a:r:p:b:"))!= -1 ) {
+	while( (opt=getopt(argc, argv, "vhstdzm:c:a:r:p:b:U:P:"))!= -1 ) {
 		switch(opt) {
 			case 'v':
 				cout << "amSynth " << VERSION << " -- compiled "
@@ -232,13 +274,22 @@ int main( int argc, char *argv[] )
 			case 'z':
 				ptest();
 				return 0;
+			case 'P':
+				initial_preset_no = atoi(optarg);
+				break;
 			default:
 				break;
 		}
 	}
 	
 	install_default_files_if_reqd();
-
+	
+	char *data_dir = br_find_data_dir (DEFAULT_PREFIX "/share");
+	char *amsynth_data_dir = br_strcat (data_dir, "/amSynth");
+	setenv ("AMSYNTH_DATA_DIR", amsynth_data_dir, 0); // don't override value passed from command line
+	free (amsynth_data_dir);
+	free (data_dir);
+	
 	// setup the configuration
 	config.Defaults ();
 	config.load ();
@@ -257,14 +308,14 @@ int main( int argc, char *argv[] )
 	// subsystem initialisation
 	//
 	
-	PresetController *presetController = NULL;
-	MidiController *midi_controller = NULL;
 	MidiInterface *midi_interface = NULL;
 	VoiceAllocationUnit *vau = NULL;
 	GenericOutput *out = NULL;
 	
 	presetController = new PresetController();
 	
+	midi_controller = new MidiController( config );
+
 	out = open_audio();
 	if (!out)
 		fatal_error("Fatal Error: open_audio() returned NULL.\n"
@@ -277,8 +328,9 @@ int main( int argc, char *argv[] )
 	vau->SetSampleRate (config.sample_rate);
 	vau->SetMaxVoices (config.polyphony);
 	out->setInput( vau );
-	
-	presetController->loadPresets(config.current_bank_file.c_str());
+
+	amsynth_load_bank(config.current_bank_file.c_str());
+	amsynth_set_preset_number(initial_preset_no);
 	
 	// errors now detected & reported in the GUI
 	out->Start();
@@ -295,15 +347,16 @@ int main( int argc, char *argv[] )
 	
 	config.alsa_seq_client_name = out->getTitle();
 	
-	midi_interface = new MidiInterface();
+	if (config.current_midi_driver.empty())
+		midi_interface = new MidiInterface();
 #endif
 	
 	// errors now detected & reported in the GUI
-	midi_interface->open(config);
-	
-	midi_controller = new MidiController( config );
-	midi_interface->SetMidiStreamReceiver(midi_controller);
-	midi_interface->Run();
+	if (midi_interface) {
+		midi_interface->open(config);
+		midi_interface->SetMidiStreamReceiver(midi_controller);
+		midi_interface->Run();
+	}
 
 	if (config.debug_drivers) std::cerr << "*** DONE :)\n\n";
   
@@ -312,36 +365,92 @@ int main( int argc, char *argv[] )
   
 	presetController->getCurrentPreset().AddListenerToAll (vau);
 
+	// prevent lash from spawning a new jack server
+	setenv("JACK_NO_START_SERVER", "1", 0);
+	
+	if (config.alsa_seq_client_id != 0 || !config.jack_client_name.empty())
+		// LASH only works with ALSA MIDI and JACK
+		amsynth_lash_init();
+
+	if (config.alsa_seq_client_id != 0) // alsa midi is active
+		amsynth_lash_set_alsa_client_id(config.alsa_seq_client_id);
+
+	if (!config.jack_client_name.empty())
+		amsynth_lash_set_jack_client_name(config.jack_client_name.c_str());
+
 	// give audio/midi threads time to start up first..
 	// if (jack) sleep (1);
 	
 	gui_init(config, *midi_controller, *vau, *presetController, out);
 	
-	gui_kit_run();
+	gui_kit_run(&amsynth_timer_callback);
 
 	DEBUGMSG("main() : GUI was terminated, shutting down cleanly..\n");
 	
+	gui_dealloc();
+	
 	/*
 	 * code to shut down cleanly..
 	 */
 
-	presetController->savePresets(config.current_bank_file.c_str ());
 	midi_controller->saveConfig();
 	
 	out->Stop ();
 
 	if (config.xruns) std::cerr << config.xruns << " audio buffer underruns occurred\n";
 	
-	midi_interface->Stop ();
+	if (midi_interface) {
+		midi_interface->Stop ();
+		delete midi_interface;
+	}
 
 	delete presetController;
 	delete midi_controller;
-	delete midi_interface;
 	delete vau;
 	delete out;
 	return 0;
 }
 
+unsigned
+amsynth_timer_callback()
+{
+	amsynth_lash_poll_events();
+	return 1;
+}
+
+void
+amsynth_midi_callback(unsigned /* timestamp */, unsigned num_bytes, unsigned char *midi_data)
+{
+	if (midi_controller)
+		midi_controller->HandleMidiData(midi_data, num_bytes);
+}
+
+void
+amsynth_save_bank(const char *filename)
+{
+	presetController->commitPreset();
+	presetController->savePresets(filename);
+}
+
+void
+amsynth_load_bank(const char *filename)
+{
+	presetController->loadPresets(filename);
+	presetController->selectPreset(presetController->getCurrPresetNumber());
+}
+
+int
+amsynth_get_preset_number()
+{
+	return presetController->getCurrPresetNumber();
+}
+
+void
+amsynth_set_preset_number(int preset_no)
+{
+	presetController->selectPreset(preset_no);
+}
+
 ///////////////////////////////////////////////////////////////////////////////
 
 void ptest ()
